<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="sk">
<context>
    <name>ExLayerCustomProperty</name>
    <message>
        <location filename="../ExLayerCustomProperty.js" line="+43"/>
        <source>Added custom property &apos;MyCustomProperty&apos; to layer &apos;0&apos;.</source>
        <translation>Pridané vlastné vlastnosť &apos;Vlastné&apos; na vrstve &apos;0&apos;.</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Add Custom Property to a Layer</source>
        <translation>Pridajte vlastnú vlastnosť na vrstvu</translation>
    </message>
    <message>
        <source>Add custom property to a layer</source>
        <translation type="vanished">Pridajte vlastnú vlastnosť na vrstvu</translation>
    </message>
</context>
</TS>
